aboutsummaryrefslogtreecommitdiff
path: root/tests/manifest/driver.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2017-04-10 13:17:22 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2017-04-10 13:17:22 +0200
commitf5a74f868477c484a58f9deb7435afa88efaefa0 (patch)
tree1f48ba750354c6cce0676054da60d6d19ede1f8b /tests/manifest/driver.cxx
parent294058e21e33c7bfbb852f8f1a73b1555aa3eace (diff)
Split machine_manifest into machine_header_manifest and machine_manifest
Diffstat (limited to 'tests/manifest/driver.cxx')
-rw-r--r--tests/manifest/driver.cxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/manifest/driver.cxx b/tests/manifest/driver.cxx
index 0f24c8a..16240a5 100644
--- a/tests/manifest/driver.cxx
+++ b/tests/manifest/driver.cxx
@@ -22,7 +22,7 @@ using namespace bbot;
// Read and parse manifest from STDIN and serialize it to STDOUT. The
// following options specify the manifest type.
//
// -m parse machine manifest
// -t parse task manifest
// -r parse result manifest
// -tq parse task request manifest
@@ -43,7 +43,7 @@ try
manifest_serializer s (cout, "stdout");
if (opt == "-m")
- machine_manifest (p).serialize (s);
+ machine_header_manifest (p).serialize (s);
else if (opt == "-t")
task_manifest (p).serialize (s);
else if (opt == "-r")
@@ -22,7 +22,7 @@ using namespace bbot;
// following options specify the manifest type.
//
-// -m parse machine manifest
+// -m parse machine header manifest
// -t parse task manifest
// -r parse result manifest